@@ -1,15 +1,13 @@
 import functools
 import random
 import socket
-import time
 from time import sleep
 import uiautomator2 as u2
 import adbutils
 import types
 import rtree
 import re
-from typing import Any, Dict, List, Literal, Union, Optional
-from http.client import HTTPResponse
+from typing import List, Literal, Union, Optional
 from lxml import etree
 from .absDriver import AbstractScriptDriver, AbstractStaticChecker, AbstractDriver
 from .adbUtils import list_forwards, remove_forward, create_forward
@@ -413,15 +411,25 @@ class _HindenWidgetFilter:
 
 
 class U2StaticDevice(u2.Device):
+    
     def __init__(self, script_driver=None):
         self.xml: etree._Element = None
-        self._script_driver = script_driver
+        self._script_driver:u2.Device = script_driver
+        self._app_current = None
 
     def __call__(self, **kwargs):
         ui = StaticU2UiObject(session=self, selector=u2.Selector(**kwargs))
         if self._script_driver:
             ui.jsonrpc = self._script_driver.jsonrpc
         return ui
+    
+    def clear_cache(self):
+        self._app_current = None
+    
+    def app_current(self):
+        if not self._app_current:
+            self._app_current = self._script_driver.app_current()
+        return self._app_current
 
     @property
     def xpath(self) -> u2.xpath.XPathEntry:
